@@ -1,22 +1,9 @@
-/***************************************************************************
- *   Copyright (C) 2015 Marco Martin <mart@kde.org>                        *
- *   Copyright (C) 2016 David Edmundson <davidedmundson@kde.org>           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2015 Marco Martin <mart@kde.org>
+ *   SPDX-FileCopyrightText: 2016 David Edmundson <davidedmundson@kde.org>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "groupingcontainment.h"
 #include "debug.h"
@@ -24,7 +11,6 @@
 #include <QDebug>
 #include <QProcess>
 
-
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 #include <QDBusPendingCallWatcher>
@@ -79,7 +65,7 @@ void GroupingContainment::showPlasmoidMenu(QQuickItem *appletInterface, int x, i
         return;
     }
 
-    Plasma::Applet *applet = appletInterface->property("_plasma_applet").value<Plasma::Applet*>();
+    Plasma::Applet *applet = appletInterface->property("_plasma_applet").value<Plasma::Applet *>();
 
     QPointF pos = appletInterface->mapToScene(QPointF(x, y));
 
@@ -100,7 +86,7 @@ void GroupingContainment::showPlasmoidMenu(QQuickItem *appletInterface, int x, i
         }
     }
 
-    //add run associated action/ remove / alternatives
+    // add run associated action/ remove / alternatives
     desktopMenu->addActions(applet->actions()->actions());
 
     if (desktopMenu->isEmpty()) {
@@ -113,14 +99,14 @@ void GroupingContainment::showPlasmoidMenu(QQuickItem *appletInterface, int x, i
     if (QScreen *screen = appletInterface->window()->screen()) {
         const QRect geo = screen->availableGeometry();
 
-        pos = QPoint(qBound(geo.left(), (int)pos.x(), geo.right() - desktopMenu->width()),
-                        qBound(geo.top(), (int)pos.y(), geo.bottom() - desktopMenu->height()));
+        pos =
+            QPoint(qBound(geo.left(), (int)pos.x(), geo.right() - desktopMenu->width()), qBound(geo.top(), (int)pos.y(), geo.bottom() - desktopMenu->height()));
     }
 
     desktopMenu->popup(pos.toPoint());
 }
 
-QPointF GroupingContainment::popupPosition(QQuickItem* visualParent, int x, int y)
+QPointF GroupingContainment::popupPosition(QQuickItem *visualParent, int x, int y)
 {
     if (!visualParent) {
         return QPointF(0, 0);
@@ -136,7 +122,7 @@ QPointF GroupingContainment::popupPosition(QQuickItem* visualParent, int x, int
     return pos;
 }
 
-void GroupingContainment::reorderItemBefore(QQuickItem* before, QQuickItem* after)
+void GroupingContainment::reorderItemBefore(QQuickItem *before, QQuickItem *after)
 {
     if (!before || !after) {
         return;
@@ -148,7 +134,7 @@ void GroupingContainment::reorderItemBefore(QQuickItem* before, QQuickItem* afte
     before->setVisible(true);
 }
 
-void GroupingContainment::reorderItemAfter(QQuickItem* after, QQuickItem* before)
+void GroupingContainment::reorderItemAfter(QQuickItem *after, QQuickItem *before)
 {
     if (!before || !after) {
         return;
