@@ -1,44 +1,30 @@
 /*
- *  Copyright 2008-2009 Lukas Appelhans <l.appelhans@gmx.de>
- *  Copyright 2010-2011 Ingomar Wesp <ingomar@wesp.name>
- *  Copyright 2013 Bhushan Shah <bhush94@gmail.com>
- *  Copyright 2015 David Rosca <nowrep@gmail.com>
+ *  SPDX-FileCopyrightText: 2008-2009 Lukas Appelhans <l.appelhans@gmx.de>
+ *  SPDX-FileCopyrightText: 2010-2011 Ingomar Wesp <ingomar@wesp.name>
+ *  SPDX-FileCopyrightText: 2013 Bhushan Shah <bhush94@gmail.com>
+ *  SPDX-FileCopyrightText: 2015 David Rosca <nowrep@gmail.com>
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of
- *  the License or (at your option) version 3 or any later version
- *  accepted by the membership of KDE e.V. (or its successor approved
- *  by the membership of KDE e.V.), which shall act as a proxy
- *  defined in Section 14 of version 3 of the license.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>
+ *  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "quicklaunch_p.h"
 
 #include <QDir>
 #include <QFileInfo>
-#include <QMimeType>
 #include <QMimeDatabase>
-#include <QStandardPaths>
+#include <QMimeType>
 #include <QRandomGenerator>
+#include <QStandardPaths>
 
-#include <KRun>
 #include <KConfig>
 #include <KConfigGroup>
-#include <KNotificationJobUiDelegate>
-#include <KFileItem>
 #include <KDesktopFile>
+#include <KFileItem>
 #include <KIO/CommandLauncherJob>
+#include <KNotificationJobUiDelegate>
 #include <KOpenWithDialog>
 #include <KPropertiesDialog>
+#include <KRun>
 
 #include <kio/global.h>
 
@@ -84,11 +70,9 @@ QVariantMap QuicklaunchPrivate::launcherData(const QUrl &url)
                     continue;
                 }
 
-                jumpListActions << QVariantMap{
-                    {QStringLiteral("name"), name},
-                    {QStringLiteral("icon"), actionGroup.readEntry("Icon")},
-                    {QStringLiteral("exec"), exec}
-                };
+                jumpListActions << QVariantMap{{QStringLiteral("name"), name},
+                                               {QStringLiteral("icon"), actionGroup.readEntry("Icon")},
+                                               {QStringLiteral("exec"), exec}};
             }
         } else {
             QMimeDatabase db;
@@ -108,12 +92,10 @@ QVariantMap QuicklaunchPrivate::launcherData(const QUrl &url)
         icon = KIO::iconNameForUrl(url);
     }
 
-    return QVariantMap{
-        {QStringLiteral("applicationName"), name},
-        {QStringLiteral("iconName"), icon},
-        {QStringLiteral("genericName"), genericName},
-        {QStringLiteral("jumpListActions"), jumpListActions}
-    };
+    return QVariantMap{{QStringLiteral("applicationName"), name},
+                       {QStringLiteral("iconName"), icon},
+                       {QStringLiteral("genericName"), genericName},
+                       {QStringLiteral("jumpListActions"), jumpListActions}};
 }
 
 void QuicklaunchPrivate::openUrl(const QUrl &url)
@@ -150,7 +132,7 @@ void QuicklaunchPrivate::addLauncher(bool isPopup)
 
 static QString locateLocal(const QString &file)
 {
-    const QString &dataPath = QStandardPaths::writableLocation(QStandardPaths::DataLocation);
+    const QString &dataPath = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
     const QString appDataPath = QStringLiteral("%1/quicklaunch").arg(dataPath);
     QDir().mkpath(appDataPath);
     return QStringLiteral("%1/%2").arg(appDataPath, file);
@@ -169,7 +151,7 @@ static QString determineNewDesktopFilePath(const QString &baseName)
 
         // Limit to [0-9] and [a-z] range.
         char newChar = generator->bounded(36);
-        newChar += newChar < 10 ? 48 : 97-10;
+        newChar += newChar < 10 ? 48 : 97 - 10;
         appendix += QLatin1Char(newChar);
 
         desktopFilePath = locateLocal(baseName + appendix + QLatin1String(".desktop"));
