@@ -1,39 +1,28 @@
 /*
- *   Copyright (C) 2007 Tobias Koenig <tokoe@kde.org>
+ *   SPDX-FileCopyrightText: 2007 Tobias Koenig <tokoe@kde.org>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License version 2 as
- *   published by the Free Software Foundation
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *   SPDX-License-Identifier: LGPL-2.0-only
  */
 
 #include "comic.h"
 
 #include <QDate>
-#include <QFileInfo>
-#include <QSettings>
-#include <QImage>
-#include <QUrl>
 #include <QDebug>
+#include <QFileInfo>
+#include <QImage>
+#include <QSettings>
 #include <QStandardPaths>
+#include <QUrl>
 
-#include <Plasma/DataContainer>
 #include <KPackage/PackageLoader>
+#include <Plasma/DataContainer>
 
 #include "cachedprovider.h"
 #include "comicproviderkross.h"
 
-ComicEngine::ComicEngine(QObject* parent, const QVariantList& args)
-    : Plasma::DataEngine(parent, args), mEmptySuffix(false)
+ComicEngine::ComicEngine(QObject *parent, const QVariantList &args)
+    : Plasma::DataEngine(parent, args)
+    , mEmptySuffix(false)
 {
     setPollingInterval(0);
     loadProviders();
@@ -45,8 +34,7 @@ ComicEngine::~ComicEngine()
 
 void ComicEngine::init()
 {
-    connect(&m_networkConfigurationManager, &QNetworkConfigurationManager::onlineStateChanged,
-            this, &ComicEngine::onOnlineStateChanged);
+    connect(&m_networkConfigurationManager, &QNetworkConfigurationManager::onlineStateChanged, this, &ComicEngine::onOnlineStateChanged);
 }
 
 void ComicEngine::onOnlineStateChanged(bool isOnline)
@@ -64,12 +52,13 @@ void ComicEngine::loadProviders()
     for (auto comic : comics) {
         mProviders << comic.pluginId();
 
-        //qDebug() << "ComicEngine::loadProviders()  service name=" << comic.name();
+        // qDebug() << "ComicEngine::loadProviders()  service name=" << comic.name();
         QStringList data;
         data << comic.name();
         QFileInfo file(comic.iconName());
         if (file.isRelative()) {
-            data << QStandardPaths::locate(QStandardPaths::GenericDataLocation, QString::fromLatin1("plasma/comics/%1/%2").arg(comic.pluginId(), comic.iconName()));
+            data << QStandardPaths::locate(QStandardPaths::GenericDataLocation,
+                                           QString::fromLatin1("plasma/comics/%1/%2").arg(comic.pluginId(), comic.iconName()));
         } else {
             data << comic.iconName();
         }
@@ -95,11 +84,7 @@ bool ComicEngine::updateSourceEvent(const QString &identifier)
             return true;
         }
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        const QStringList parts = identifier.split(QLatin1Char(':'), QString::KeepEmptyParts);
-#else
         const QStringList parts = identifier.split(QLatin1Char(':'), Qt::KeepEmptyParts);
-#endif
 
         // check whether it is cached, make sure second part present
         if (parts.count() > 1 && CachedProvider::isCached(identifier)) {
@@ -108,8 +93,8 @@ bool ComicEngine::updateSourceEvent(const QString &identifier)
 
             ComicProvider *provider = new CachedProvider(this, args);
             m_jobs[identifier] = provider;
-            connect(provider, SIGNAL(finished(ComicProvider*)), this, SLOT(finished(ComicProvider*)));
-            connect(provider, SIGNAL(error(ComicProvider*)), this, SLOT(error(ComicProvider*)));
+            connect(provider, &ComicProvider::finished, this, &ComicEngine::finished);
+            connect(provider, &ComicProvider::error, this, &ComicEngine::error);
             return true;
         }
 
@@ -147,12 +132,13 @@ bool ComicEngine::updateSourceEvent(const QString &identifier)
         QVariantList args;
         ComicProvider *provider = nullptr;
 
-        //const QString type = service->property(QLatin1String("X-KDE-PlasmaComicProvider-SuffixType"), QVariant::String).toString();
+        // const QString type = service->property(QLatin1String("X-KDE-PlasmaComicProvider-SuffixType"), QVariant::String).toString();
         const QString type = pkg.metadata().value(QStringLiteral("X-KDE-PlasmaComicProvider-SuffixType"));
         if (type == QLatin1String("Date")) {
             QDate date = QDate::fromString(parts[1], Qt::ISODate);
-            if (!date.isValid())
+            if (!date.isValid()) {
                 date = QDate::currentDate();
+            }
 
             args << QLatin1String("Date") << date;
         } else if (type == QLatin1String("Number")) {
@@ -162,7 +148,7 @@ bool ComicEngine::updateSourceEvent(const QString &identifier)
         }
         args << QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("plasma/comics/") + parts[0] + QLatin1String("/metadata.desktop"));
 
-        //provider = service->createInstance<ComicProvider>(this, args);
+        // provider = service->createInstance<ComicProvider>(this, args);
         provider = new ComicProviderKross(this, args);
         if (!provider) {
             setData(identifier, QLatin1String("Error"), true);
@@ -172,8 +158,8 @@ bool ComicEngine::updateSourceEvent(const QString &identifier)
 
         m_jobs[identifier] = provider;
 
-        connect(provider, SIGNAL(finished(ComicProvider*)), this, SLOT(finished(ComicProvider*)));
-        connect(provider, SIGNAL(error(ComicProvider*)), this, SLOT(error(ComicProvider*)));
+        connect(provider, &ComicProvider::finished, this, &ComicEngine::finished);
+        connect(provider, &ComicProvider::error, this, &ComicEngine::error);
         return true;
     }
 }
@@ -200,15 +186,14 @@ void ComicEngine::finished(ComicProvider *provider)
         mIdentifierError.clear();
     }
     // comic strip with error worked now
-    if (!mIdentifierError.isEmpty() && (mIdentifierError == provider->identifier())){
+    if (!mIdentifierError.isEmpty() && (mIdentifierError == provider->identifier())) {
         mIdentifierError.clear();
     }
 
     // store in cache if it's not the response of a CachedProvider,
     // if there is a valid image and if there is a next comic
     // (if we're on today's comic it could become stale)
-    if (!provider->inherits("CachedProvider") && !provider->image().isNull() &&
-         !provider->nextIdentifier().isEmpty()) {
+    if (!provider->inherits("CachedProvider") && !provider->image().isNull() && !provider->nextIdentifier().isEmpty()) {
         CachedProvider::Settings info;
 
         info[QLatin1String("websiteUrl")] = provider->websiteUrl().toString(QUrl::PrettyDecoded);
@@ -224,7 +209,7 @@ void ComicEngine::finished(ComicProvider *provider)
         info[QLatin1String("isLeftToRight")] = isLeftToRight.setNum(provider->isLeftToRight());
         info[QLatin1String("isTopToBottom")] = isTopToBottom.setNum(provider->isTopToBottom());
 
-        //data that should be only written if available
+        // data that should be only written if available
         if (!provider->comicAuthor().isEmpty()) {
             info[QLatin1String("comicAuthor")] = provider->comicAuthor();
         }
@@ -263,8 +248,9 @@ void ComicEngine::error(ComicProvider *provider)
      * set initially, so we have to remove the 'faked' suffix
      * here again to not confuse the applet.
      */
-    if (provider->isCurrent())
+    if (provider->isCurrent()) {
         identifier = identifier.left(identifier.indexOf(QLatin1Char(':')) + 1);
+    }
 
     setData(identifier, QLatin1String("Identifier"), identifier);
     setData(identifier, QLatin1String("Error"), true);
@@ -294,8 +280,9 @@ void ComicEngine::setComicData(ComicProvider *provider)
      * set initially, so we have to remove the 'faked' suffix
      * here again to not confuse the applet.
      */
-    if (provider->isCurrent())
+    if (provider->isCurrent()) {
         identifier = identifier.left(identifier.indexOf(QLatin1Char(':')) + 1);
+    }
 
     setData(identifier, QLatin1String("Image"), provider->image());
     setData(identifier, QLatin1String("Website Url"), provider->websiteUrl());
@@ -317,13 +304,13 @@ void ComicEngine::setComicData(ComicProvider *provider)
 
 QString ComicEngine::lastCachedIdentifier(const QString &identifier) const
 {
-        const QString id = identifier.left(identifier.indexOf(QLatin1Char(':')));
-        QString data = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/plasma_engine_comic/");
-        data += QString::fromLatin1(QUrl::toPercentEncoding(id));
-        QSettings settings(data + QLatin1String(".conf"), QSettings::IniFormat);
-        QString previousIdentifier = settings.value(QLatin1String("lastCachedStripIdentifier"), QString()).toString();
+    const QString id = identifier.left(identifier.indexOf(QLatin1Char(':')));
+    QString data = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/plasma_engine_comic/");
+    data += QString::fromLatin1(QUrl::toPercentEncoding(id));
+    QSettings settings(data + QLatin1String(".conf"), QSettings::IniFormat);
+    QString previousIdentifier = settings.value(QLatin1String("lastCachedStripIdentifier"), QString()).toString();
 
-        return previousIdentifier;
+    return previousIdentifier;
 }
 
 K_EXPORT_PLASMA_DATAENGINE_WITH_JSON(comic, ComicEngine, "plasma-dataengine-comic.json")
