@@ -1,46 +1,30 @@
 /*
- *   Copyright (C) 2008 Petri Damstén <damu@iki.fi>
- *   Copyright (C) 2010 Matthias Fuchs <mat69@gmx.net>
+ *   SPDX-FileCopyrightText: 2008 Petri Damstén <damu@iki.fi>
+ *   SPDX-FileCopyrightText: 2010 Matthias Fuchs <mat69@gmx.net>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License version 2 as
- *   published by the Free Software Foundation
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *   SPDX-License-Identifier: LGPL-2.0-only
  */
 
 #include "comicproviderwrapper.h"
 #include "comicproviderkross.h"
-#include "comicprovider.h"
 
-#include <QTimer>
-#include <QBuffer>
-#include <QPainter>
-#include <QTextCodec>
-#include <QUrl>
-#include <QDebug>
-#include <QStandardPaths>
-#include <Plasma/Package>
 #include <Kross/Core/Action>
 #include <Kross/Core/Interpreter>
 #include <Kross/Core/Manager>
-
-#include <Plasma/PluginLoader>
+#include <Plasma/Package>
+#include <QDebug>
+#include <QPainter>
+#include <QStandardPaths>
+#include <QTextCodec>
+#include <QTimer>
+#include <QUrl>
 
 QStringList ComicProviderWrapper::mExtensions;
 
 ImageWrapper::ImageWrapper(QObject *parent, const QByteArray &data)
-  : QObject(parent),
-    mImage(QImage::fromData(data)),
-    mRawData(data)
+    : QObject(parent)
+    , mImage(QImage::fromData(data))
+    , mRawData(data)
 {
     resetImageReader();
 }
@@ -81,7 +65,7 @@ void ImageWrapper::resetImageReader()
     if (mBuffer.isOpen()) {
         mBuffer.close();
     }
-    rawData(); //to update the rawData if needed
+    rawData(); // to update the rawData if needed
     mBuffer.setBuffer(&mRawData);
     mBuffer.open(QIODevice::ReadOnly);
     mImageReader.setDevice(&mBuffer);
@@ -97,10 +81,9 @@ QImage ImageWrapper::read()
     return mImageReader.read();
 }
 
-
 DateWrapper::DateWrapper(QObject *parent, const QDate &date)
-: QObject(parent)
-, mDate(date)
+    : QObject(parent)
+    , mDate(date)
 {
 }
 
@@ -121,7 +104,7 @@ QDate DateWrapper::fromVariant(const QVariant &variant)
     } else if (variant.type() == QVariant::String) {
         return QDate::fromString(variant.toString(), Qt::ISODate);
     } else {
-        DateWrapper* dw = qobject_cast<DateWrapper*>(variant.value<QObject*>());
+        DateWrapper *dw = qobject_cast<DateWrapper *>(variant.value<QObject *>());
         if (dw) {
             return dw->date();
         }
@@ -129,17 +112,17 @@ QDate DateWrapper::fromVariant(const QVariant &variant)
     return QDate();
 }
 
-QObject* DateWrapper::addDays(int ndays)
+QObject *DateWrapper::addDays(int ndays)
 {
     return new DateWrapper(this, mDate.addDays(ndays));
 }
 
-QObject* DateWrapper::addMonths(int nmonths)
+QObject *DateWrapper::addMonths(int nmonths)
 {
     return new DateWrapper(this, mDate.addMonths(nmonths));
 }
 
-QObject* DateWrapper::addYears(int nyears)
+QObject *DateWrapper::addYears(int nyears)
 {
     return new DateWrapper(this, mDate.addYears(nyears));
 }
@@ -220,72 +203,72 @@ int DateWrapper::year() const
 }
 
 StaticDateWrapper::StaticDateWrapper(QObject *parent)
-: QObject(parent)
+    : QObject(parent)
 {
 }
 
-QObject* StaticDateWrapper::currentDate()
+QObject *StaticDateWrapper::currentDate()
 {
     return new DateWrapper(this, QDate::currentDate());
 }
 
-QObject* StaticDateWrapper::fromJulianDay(int jd)
+QObject *StaticDateWrapper::fromJulianDay(int jd)
 {
     return new DateWrapper(this, QDate::fromJulianDay(jd));
 }
 
-QObject* StaticDateWrapper::fromString(const QString &string, int format)
+QObject *StaticDateWrapper::fromString(const QString &string, int format)
 {
     return new DateWrapper(this, QDate::fromString(string, (Qt::DateFormat)format));
 }
 
-QObject* StaticDateWrapper::fromString(const QString &string, const QString &format)
+QObject *StaticDateWrapper::fromString(const QString &string, const QString &format)
 {
     return new DateWrapper(this, QDate::fromString(string, format));
 }
 
-bool StaticDateWrapper::isLeapYear (int year)
+bool StaticDateWrapper::isLeapYear(int year)
 {
     return QDate::isLeapYear(year);
 }
 
-bool StaticDateWrapper::isValid (int year, int month, int day)
+bool StaticDateWrapper::isValid(int year, int month, int day)
 {
     return QDate::isValid(year, month, day);
 }
 
-QString StaticDateWrapper::longDayName (int weekday)
+QString StaticDateWrapper::longDayName(int weekday)
 {
     return QLocale::system().dayName(weekday, QLocale::LongFormat);
 }
 
-QString StaticDateWrapper::longMonthName (int month)
+QString StaticDateWrapper::longMonthName(int month)
 {
     return QLocale::system().monthName(month, QLocale::LongFormat);
 }
 
-QString StaticDateWrapper::shortDayName (int weekday)
+QString StaticDateWrapper::shortDayName(int weekday)
 {
     return QLocale::system().dayName(weekday, QLocale::ShortFormat);
 }
 
-QString StaticDateWrapper::shortMonthName (int month)
+QString StaticDateWrapper::shortMonthName(int month)
 {
     return QLocale::system().monthName(month, QLocale::ShortFormat);
 }
 
 ComicProviderWrapper::ComicProviderWrapper(ComicProviderKross *parent)
-    : QObject(parent),
-      mAction(nullptr),
-      mProvider(parent),
-      mKrossImage(nullptr),
-      mPackage(nullptr),
-      mRequests(0),
-      mIdentifierSpecified(false),
-      mIsLeftToRight(true),
-      mIsTopToBottom(true)
+    : QObject(parent)
+    , mAction(nullptr)
+    , mProvider(parent)
+    , mKrossImage(nullptr)
+    , mPackage(nullptr)
+    , mRequests(0)
+    , mIdentifierSpecified(false)
+    , mIsLeftToRight(true)
+    , mIsTopToBottom(true)
 {
-    QTimer::singleShot(0, this, SLOT(init()));
+    QTimer::singleShot(0, this, &ComicProviderWrapper::init);
 }
 
 ComicProviderWrapper::~ComicProviderWrapper()
@@ -295,8 +278,10 @@ ComicProviderWrapper::~ComicProviderWrapper()
 
 void ComicProviderWrapper::init()
 {
-    const QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("plasma/comics/") + mProvider->pluginName() + QLatin1Char('/'),QStandardPaths::LocateDirectory);
-    //qDebug() << "ComicProviderWrapper::init() package is" << mProvider->pluginName() << " at " <<  path;
+    const QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
+                                                QLatin1String("plasma/comics/") + mProvider->pluginName() + QLatin1Char('/'),
+                                                QStandardPaths::LocateDirectory);
+    // qDebug() << "ComicProviderWrapper::init() package is" << mProvider->pluginName() << " at " <<  path;
 
     if (!path.isEmpty()) {
         mPackage = new KPackage::Package(ComicProviderKross::packageStructure());
@@ -305,15 +290,15 @@ void ComicProviderWrapper::init()
         if (mPackage->isValid()) {
             // QString mainscript = mPackage->filePath("mainscript")
             // doesn't work because the mainscript file can be a different Kross script type ending with main.es or main.kjs etc.
-            // Maybe this should be added to Plasma::Package or maybe directly change the packagestructure mainscript definition as "main.es" and avoid all this.
-            // https://techbase.kde.org/Development/Tutorials/Plasma4/ComicPlugin#Package_Structure has main.es defined as mainscript.
-            // Also Package::isValid() fails because the mainscript search fails to find the "main" file from mainscript.
+            // Maybe this should be added to Plasma::Package or maybe directly change the packagestructure mainscript definition as "main.es" and avoid all
+            // this. https://techbase.kde.org/Development/Tutorials/Plasma4/ComicPlugin#Package_Structure has main.es defined as mainscript. Also
+            // Package::isValid() fails because the mainscript search fails to find the "main" file from mainscript.
 
             QString mainscript = mPackage->filePath("scripts") + QLatin1String("/main");
             QFileInfo info(mainscript);
             for (int i = 0; i < extensions().count() && !info.exists(); ++i) {
-                    info.setFile(mainscript + extensions().value(i));
-                    //qDebug() << "ComicProviderWrapper::init() mainscript found as" << info.filePath();
+                info.setFile(mainscript + extensions().value(i));
+                // qDebug() << "ComicProviderWrapper::init() mainscript found as" << info.filePath();
             }
 
             if (info.exists()) {
@@ -334,14 +319,14 @@ void ComicProviderWrapper::init()
     }
 }
 
-const QStringList& ComicProviderWrapper::extensions() const
+const QStringList &ComicProviderWrapper::extensions() const
 {
     if (mExtensions.isEmpty()) {
-        Kross::InterpreterInfo* info;
+        Kross::InterpreterInfo *info;
         QStringList list;
         QString wildcards;
 
-        foreach(const QString &interpretername, Kross::Manager::self().interpreters()) {
+        foreach (const QString &interpretername, Kross::Manager::self().interpreters()) {
             info = Kross::Manager::self().interpreterInfo(interpretername);
             wildcards = info->wildcard();
             wildcards.remove(QLatin1Char('*'));
@@ -367,7 +352,7 @@ ComicProvider::IdentifierType ComicProviderWrapper::identifierType() const
 
 QImage ComicProviderWrapper::comicImage()
 {
-    ImageWrapper* img = qobject_cast<ImageWrapper*>(callFunction(QLatin1String("image")).value<QObject*>());
+    ImageWrapper *img = qobject_cast<ImageWrapper *>(callFunction(QLatin1String("image")).value<QObject *>());
     if (functionCalled() && img) {
         return img->image();
     }
@@ -380,7 +365,7 @@ QImage ComicProviderWrapper::comicImage()
 QVariant ComicProviderWrapper::identifierToScript(const QVariant &identifier)
 {
     if (identifierType() == ComicProvider::DateIdentifier && identifier.type() != QVariant::Bool) {
-        return QVariant::fromValue(qobject_cast<QObject*>(new DateWrapper(this, identifier.toDate())));
+        return QVariant::fromValue(qobject_cast<QObject *>(new DateWrapper(this, identifier.toDate())));
     }
     return identifier;
 }
@@ -408,28 +393,23 @@ void ComicProviderWrapper::checkIdentifier(QVariant *identifier)
 {
     switch (identifierType()) {
     case DateIdentifier:
-        if (!mLastIdentifier.isNull() && !identifier->isNull() &&
-             (!mIdentifierSpecified || identifier->toDate() > mLastIdentifier.toDate())) {
+        if (!mLastIdentifier.isNull() && !identifier->isNull() && (!mIdentifierSpecified || identifier->toDate() > mLastIdentifier.toDate())) {
             *identifier = mLastIdentifier;
         }
-        if (!mFirstIdentifier.isNull() && !identifier->isNull() &&
-             identifier->toDate() < mFirstIdentifier.toDate()) {
+        if (!mFirstIdentifier.isNull() && !identifier->isNull() && identifier->toDate() < mFirstIdentifier.toDate()) {
             *identifier = mFirstIdentifier;
         }
         break;
     case NumberIdentifier:
-        if (!mLastIdentifier.isNull() && !identifier->isNull() &&
-           (!mIdentifierSpecified || identifier->toInt() > mLastIdentifier.toInt())) {
+        if (!mLastIdentifier.isNull() && !identifier->isNull() && (!mIdentifierSpecified || identifier->toInt() > mLastIdentifier.toInt())) {
             *identifier = mLastIdentifier;
         }
-        if (!mFirstIdentifier.isNull() && !identifier->isNull() &&
-             identifier->toInt() < mFirstIdentifier.toInt()) {
+        if (!mFirstIdentifier.isNull() && !identifier->isNull() && identifier->toInt() < mFirstIdentifier.toInt()) {
             *identifier = mFirstIdentifier;
         }
         break;
     case StringIdentifier:
-        if (!mLastIdentifier.isNull() && !mLastIdentifier.toString().isEmpty() &&
-             !mIdentifierSpecified) {
+        if (!mLastIdentifier.isNull() && !mLastIdentifier.toString().isEmpty() && !mIdentifierSpecified) {
             *identifier = mLastIdentifier;
         }
         break;
@@ -626,12 +606,12 @@ QVariant ComicProviderWrapper::lastIdentifierVariant() const
 
 QVariant ComicProviderWrapper::nextIdentifierVariant() const
 {
-    //either handle both previousIdentifier and nextIdentifier or handle none
+    // either handle both previousIdentifier and nextIdentifier or handle none
     if (mPreviousIdentifier.isNull() && mNextIdentifier.isNull()) {
         switch (identifierType()) {
         case DateIdentifier:
-            if ((mLastIdentifier.isNull() && mIdentifier.toDate() < QDate::currentDate()) ||
-                 (!mLastIdentifier.isNull() && mIdentifier.toDate() < mLastIdentifier.toDate())) {
+            if ((mLastIdentifier.isNull() && mIdentifier.toDate() < QDate::currentDate())
+                || (!mLastIdentifier.isNull() && mIdentifier.toDate() < mLastIdentifier.toDate())) {
                 return mIdentifier.toDate().addDays(1);
             } else {
                 return false;
@@ -645,19 +625,17 @@ QVariant ComicProviderWrapper::nextIdentifierVariant() const
         case StringIdentifier:
             break;
         }
-    //check if the nextIdentifier is correct
+        // check if the nextIdentifier is correct
     } else if (!mNextIdentifier.isNull()) {
-        //no nextIdentifier if mIdentifier == mLastIdentifier or if no identifier has been specified
+        // no nextIdentifier if mIdentifier == mLastIdentifier or if no identifier has been specified
         switch (identifierType()) {
         case DateIdentifier:
-            if ((!mLastIdentifier.isNull() && (mIdentifier.toDate() == mLastIdentifier.toDate())) ||
-                 !mIdentifierSpecified) {
+            if ((!mLastIdentifier.isNull() && (mIdentifier.toDate() == mLastIdentifier.toDate())) || !mIdentifierSpecified) {
                 return false;
             }
             break;
         case NumberIdentifier:
-            if ((!mLastIdentifier.isNull() && (mIdentifier.toInt() == mLastIdentifier.toInt())) ||
-                 !mIdentifierSpecified) {
+            if ((!mLastIdentifier.isNull() && (mIdentifier.toInt() == mLastIdentifier.toInt())) || !mIdentifierSpecified) {
                 return false;
             }
             break;
@@ -673,7 +651,7 @@ QVariant ComicProviderWrapper::nextIdentifierVariant() const
 
 QVariant ComicProviderWrapper::previousIdentifierVariant() const
 {
-    //either handle both previousIdentifier and nextIdentifier or handle none
+    // either handle both previousIdentifier and nextIdentifier or handle none
     if (mPreviousIdentifier.isNull() && mNextIdentifier.isNull()) {
         switch (identifierType()) {
         case DateIdentifier:
@@ -683,8 +661,7 @@ QVariant ComicProviderWrapper::previousIdentifierVariant() const
                 return false;
             }
         case NumberIdentifier:
-            if ((mFirstIdentifier.isNull() && mIdentifier.toInt() > 1) ||
-                 (!mFirstIdentifier.isNull() && mIdentifier.toInt() > mFirstIdentifier.toInt())) {
+            if ((mFirstIdentifier.isNull() && mIdentifier.toInt() > 1) || (!mFirstIdentifier.isNull() && mIdentifier.toInt() > mFirstIdentifier.toInt())) {
                 return mIdentifier.toInt() - 1;
             } else {
                 return false;
@@ -693,7 +670,7 @@ QVariant ComicProviderWrapper::previousIdentifierVariant() const
             break;
         }
     } else if (!mPreviousIdentifier.isNull()) {
-        //no previousIdentifier if mIdentifier == mFirstIdentifier
+        // no previousIdentifier if mIdentifier == mFirstIdentifier
         switch (identifierType()) {
         case DateIdentifier:
             if (!mFirstIdentifier.isNull() && (mIdentifier.toDate() == mFirstIdentifier.toDate())) {
@@ -717,8 +694,7 @@ void ComicProviderWrapper::pageRetrieved(int id, const QByteArray &data)
     --mRequests;
     if (id == Image) {
         mKrossImage = new ImageWrapper(this, data);
-        callFunction(QLatin1String("pageRetrieved"), QVariantList() << id <<
-                      QVariant::fromValue(qobject_cast<QObject*>(mKrossImage)));
+        callFunction(QLatin1String("pageRetrieved"), QVariantList() << id << QVariant::fromValue(qobject_cast<QObject *>(mKrossImage)));
         if (mRequests < 1) { // Don't finish if we still have pageRequests
             finished();
         }
@@ -749,7 +725,7 @@ void ComicProviderWrapper::redirected(int id, const QUrl &newUrl)
 {
     --mRequests;
     callFunction(QLatin1String("redirected"), QVariantList() << id << newUrl);
-    if (mRequests < 1) { //Don't finish while there are still requests
+    if (mRequests < 1) { // Don't finish while there are still requests
         finished();
     }
 }
@@ -778,7 +754,7 @@ void ComicProviderWrapper::requestPage(const QString &url, int id, const QVarian
 {
     QMap<QString, QString> map;
 
-    foreach (const QString& key, infos.keys()) {
+    foreach (const QString &key, infos.keys()) {
         map[key] = infos[key].toString();
     }
     mProvider->requestPage(QUrl(url), id, map);
@@ -789,14 +765,13 @@ void ComicProviderWrapper::requestRedirectedUrl(const QString &url, int id, cons
 {
     QMap<QString, QString> map;
 
-    foreach (const QString& key, infos.keys()) {
+    foreach (const QString &key, infos.keys()) {
         map[key] = infos[key].toString();
     }
     mProvider->requestRedirectedUrl(QUrl(url), id, map);
     ++mRequests;
 }
 
-
 bool ComicProviderWrapper::functionCalled() const
 {
     return mFuncFound;
@@ -828,7 +803,7 @@ void ComicProviderWrapper::combine(const QVariant &image, PositionType position)
             return;
         }
     } else {
-        ImageWrapper* img = qobject_cast<ImageWrapper*>(image.value<QObject*>());
+        ImageWrapper *img = qobject_cast<ImageWrapper *>(image.value<QObject *>());
         if (img) {
             header = img->image();
         } else {
@@ -840,16 +815,16 @@ void ComicProviderWrapper::combine(const QVariant &image, PositionType position)
     int width = 0;
 
     switch (position) {
-        case Top:
-        case Bottom:
-            height = header.height() + comic.height();
-            width = (header.width() >= comic.width()) ? header.width() : comic.width();
-            break;
-        case Left:
-        case Right:
-            height = (header.height() >= comic.height()) ? header.height() : comic.height();
-            width = header.width() + comic.width();
-            break;
+    case Top:
+    case Bottom:
+        height = header.height() + comic.height();
+        width = (header.width() >= comic.width()) ? header.width() : comic.width();
+        break;
+    case Left:
+    case Right:
+        height = (header.height() >= comic.height()) ? header.height() : comic.height();
+        width = header.width() + comic.width();
+        break;
     }
 
     QImage img = QImage(QSize(width, height), QImage::Format_RGB32);
@@ -862,30 +837,29 @@ void ComicProviderWrapper::combine(const QVariant &image, PositionType position)
     QPoint comicPos;
 
     switch (position) {
-        case Top:
-            headerPos = QPoint(((width - header.width()) / 2), 0);
-            comicPos = QPoint(((width - comic.width()) / 2), header.height());
-            break;
-        case Bottom:
-            headerPos = QPoint(((width - header.width()) / 2), comic.height());
-            comicPos = QPoint(((width - comic.width()) / 2), 0);
-            break;
-        case Left:
-            headerPos = QPoint(0, ((height - header.height()) / 2));
-            comicPos = QPoint(header.width(), ((height - comic.height()) / 2));
-            break;
-        case Right:
-            headerPos = QPoint(comic.width(), ((height - header.height()) / 2));
-            comicPos = QPoint(0, ((height - comic.height()) / 2));
-            break;
+    case Top:
+        headerPos = QPoint(((width - header.width()) / 2), 0);
+        comicPos = QPoint(((width - comic.width()) / 2), header.height());
+        break;
+    case Bottom:
+        headerPos = QPoint(((width - header.width()) / 2), comic.height());
+        comicPos = QPoint(((width - comic.width()) / 2), 0);
+        break;
+    case Left:
+        headerPos = QPoint(0, ((height - header.height()) / 2));
+        comicPos = QPoint(header.width(), ((height - comic.height()) / 2));
+        break;
+    case Right:
+        headerPos = QPoint(comic.width(), ((height - header.height()) / 2));
+        comicPos = QPoint(0, ((height - comic.height()) / 2));
+        break;
     }
     painter.drawImage(headerPos, header);
     painter.drawImage(comicPos, comic);
     mKrossImage->setImage(img);
 }
 
-QObject* ComicProviderWrapper::image()
+QObject *ComicProviderWrapper::image()
 {
-    return qobject_cast<QObject*>(mKrossImage);
+    return qobject_cast<QObject *>(mKrossImage);
 }
-
