@@ -1,52 +1,38 @@
 /*
- * Copyright (C) 2007,2008 Petri Damstén <damu@iki.fi>
- * Copyright (C) 2020 Alexander Lohnau <alexander.lohnau@gmx.de>
+ * SPDX-FileCopyrightText: 2007, 2008 Petri Damstén <damu@iki.fi>
+ * SPDX-FileCopyrightText: 2020 Alexander Lohnau <alexander.lohnau@gmx.de>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "converterrunner.h"
 
-#include <QGuiApplication>
-#include <QClipboard>
-#include <QDesktopServices>
-#include <QDebug>
 #include <KLocalizedString>
+#include <QClipboard>
+#include <QDebug>
+#include <QDesktopServices>
+#include <QGuiApplication>
 
 #include <cmath>
 
-ConverterRunner::ConverterRunner(QObject *parent, const QVariantList &args)
-    : Plasma::AbstractRunner(parent, args)
+ConverterRunner::ConverterRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
+    : Plasma::AbstractRunner(parent, metaData, args)
 {
     setObjectName(QStringLiteral("Converter"));
-    //can not ignore commands: we have things like m4
-    setIgnoredTypes(Plasma::RunnerContext::Directory | Plasma::RunnerContext::File |
-        Plasma::RunnerContext::NetworkLocation);
 
-    const QString description = i18n("Converts the value of :q: when :q: is made up of "
-                                     "\"value unit [>, to, as, in] unit\". You can use the "
-                                     "Unit converter applet to find all available units.");
+    const QString description = i18n(
+        "Converts the value of :q: when :q: is made up of "
+        "\"value unit [>, to, as, in] unit\". You can use the "
+        "Unit converter applet to find all available units.");
     addSyntax(Plasma::RunnerSyntax(QStringLiteral(":q:"), description));
 }
 
 void ConverterRunner::init()
 {
     valueRegex = QRegularExpression(QStringLiteral("^([0-9,./+-]+)"));
-    const QStringList conversionWords = i18nc("list of words that can used as amount of 'unit1' [in|to|as] 'unit2'",
-                                              "in;to;as").split(QLatin1Char(';'));
+    const QStringList conversionWords = i18nc("list of words that can used as amount of 'unit1' [in|to|as] 'unit2'", "in;to;as").split(QLatin1Char(';'));
     QString conversionRegex;
-    for (const auto &word: conversionWords) {
+    for (const auto &word : conversionWords) {
         conversionRegex.append(QLatin1Char(' ') + word + QStringLiteral(" |"));
     }
     conversionRegex.append(QStringLiteral(" ?> ?"));
@@ -56,22 +42,17 @@ void ConverterRunner::init()
 
     insertCompatibleUnits();
 
-    addAction(copyActionId, QIcon::fromTheme(QStringLiteral("edit-copy")),
-              i18n("Copy number"));
-    addAction(copyUnitActionId, QIcon::fromTheme(QStringLiteral("edit-copy")),
-              i18n("Copy unit and number"));
+    addAction(copyActionId, QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy number"));
+    addAction(copyUnitActionId, QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy unit and number"));
     actionList = {action(copyActionId), action(copyUnitActionId)};
+    setMinLetterCount(2);
+    setMatchRegex(valueRegex);
 }
 
 ConverterRunner::~ConverterRunner() = default;
 
 void ConverterRunner::match(Plasma::RunnerContext &context)
 {
-    const QString term = context.query();
-    if (term.size() < 2 || !context.isValid()) {
-        return;
-    }
-
     const QRegularExpressionMatch valueRegexMatch = valueRegex.match(context.query());
     if (!valueRegexMatch.hasMatch()) {
         return;
@@ -109,9 +90,8 @@ void ConverterRunner::match(Plasma::RunnerContext &context)
 
     const double numberValue = numberDataPair.second;
     QList<Plasma::QueryMatch> matches;
-    for (const KUnitConversion::Unit &outputUnit: outputUnits) {
-        KUnitConversion::Value outputValue = inputCategory.convert(
-            KUnitConversion::Value(numberValue, inputUnit), outputUnit);
+    for (const KUnitConversion::Unit &outputUnit : outputUnits) {
+        KUnitConversion::Value outputValue = inputCategory.convert(KUnitConversion::Value(numberValue, inputUnit), outputUnit);
         if (!outputValue.isValid() || inputUnit == outputUnit) {
             continue;
         }
@@ -127,19 +107,13 @@ void ConverterRunner::match(Plasma::RunnerContext &context)
         }
         match.setData(outputValue.number());
         match.setRelevance(1.0 - std::abs(std::log10(outputValue.number())) / 50.0);
+        match.setActions(actionList);
         matches.append(match);
     }
 
     context.addMatches(matches);
 }
 
-QList<QAction *> ConverterRunner::actionsForMatch(const Plasma::QueryMatch &match)
-{
-    Q_UNUSED(match)
-
-    return actionList;
-}
-
 void ConverterRunner::run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &match)
 {
     Q_UNUSED(context)
@@ -163,11 +137,7 @@ QPair<bool, double> ConverterRunner::stringToDouble(const QStringRef &value)
 
 QPair<bool, double> ConverterRunner::getValidatedNumberValue(const QString &value)
 {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const auto fractionParts = value.splitRef(QLatin1Char('/'), QString::SkipEmptyParts);
-#else
     const auto fractionParts = value.splitRef(QLatin1Char('/'), Qt::SkipEmptyParts);
-#endif
     if (fractionParts.isEmpty() || fractionParts.count() > 2) {
         return {false, 0};
     }
@@ -193,8 +163,7 @@ QPair<bool, double> ConverterRunner::getValidatedNumberValue(const QString &valu
     }
 }
 
-QList<KUnitConversion::Unit> ConverterRunner::createResultUnits(QString &outputUnitString,
-                                                                const KUnitConversion::UnitCategory &category)
+QList<KUnitConversion::Unit> ConverterRunner::createResultUnits(QString &outputUnitString, const KUnitConversion::UnitCategory &category)
 {
     QList<KUnitConversion::Unit> units;
     if (!outputUnitString.isEmpty()) {
@@ -204,9 +173,9 @@ QList<KUnitConversion::Unit> ConverterRunner::createResultUnits(QString &outputU
         } else {
             // Autocompletion for the target units
             outputUnitString = outputUnitString.toUpper();
-            for (const auto &unitStringKey: compatibleUnits.keys()) {
-                if (unitStringKey.startsWith(outputUnitString)) {
-                    outputUnit = category.unit(compatibleUnits.value(unitStringKey));
+            for (auto it = compatibleUnits.constBegin(); it != compatibleUnits.constEnd(); it++) {
+                if (it.key().startsWith(outputUnitString)) {
+                    outputUnit = category.unit(it.value());
                     if (!units.contains(outputUnit)) {
                         units << outputUnit;
                     }
@@ -231,13 +200,12 @@ QList<KUnitConversion::Unit> ConverterRunner::createResultUnits(QString &outputU
 void ConverterRunner::insertCompatibleUnits()
 {
     // Add all currency symbols to the map, if their ISO code is supported by backend
-    const QList<QLocale> allLocales = QLocale::matchingLocales(
-        QLocale::AnyLanguage, QLocale::AnyScript, QLocale::AnyCountry);
+    const QList<QLocale> allLocales = QLocale::matchingLocales(QLocale::AnyLanguage, QLocale::AnyScript, QLocale::AnyCountry);
     KUnitConversion::UnitCategory currencyCategory = converter.category(QStringLiteral("Currency"));
     const QStringList availableISOCodes = currencyCategory.allUnits();
     QRegularExpression hasCurrencyRegex = QRegularExpression(QStringLiteral("\\p{Sc}"));
     hasCurrencyRegex.optimize();
-    for (const auto &currencyLocale: allLocales) {
+    for (const auto &currencyLocale : allLocales) {
         const QString symbol = currencyLocale.currencySymbol(QLocale::CurrencySymbol);
         const QString isoCode = currencyLocale.currencySymbol(QLocale::CurrencyIsoCode);
 
@@ -250,8 +218,10 @@ void ConverterRunner::insertCompatibleUnits()
     }
 
     // Add all units as uppercase in the map
-    for (const auto &category: converter.categories()) {
-        for (const auto &unit: category.allUnits()) {
+    const auto categories = converter.categories();
+    for (const auto &category : categories) {
+        const auto allUnits = category.allUnits();
+        for (const auto &unit : allUnits) {
             compatibleUnits.insert(unit.toUpper(), unit);
         }
     }
