@@ -5,21 +5,20 @@
 
 #include "dictionarymatchengine.h"
 #include <KRunner/AbstractRunner>
-#include <QThread>
-#include <QMetaMethod>
-#include <QDebug>
-#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
 #include <QDeadlineTimer>
-#endif
+#include <QDebug>
+#include <QMetaMethod>
+#include <QThread>
+
 DictionaryMatchEngine::DictionaryMatchEngine(Plasma::DataEngine *dictionaryEngine, QObject *parent)
-    : QObject(parent),
-      m_dictionaryEngine(dictionaryEngine)
+    : QObject(parent)
+    , m_dictionaryEngine(dictionaryEngine)
 {
     /* We have to connect source in two different places, due to the difference in
      * how the connection is made based on data availability. There are two cases,
      * and this extra connection handles the second case. */
     Q_ASSERT(m_dictionaryEngine);
-    connect(m_dictionaryEngine, SIGNAL(sourceAdded(QString)), this, SLOT(sourceAdded(QString)));
+    connect(m_dictionaryEngine, &Plasma::DataEngine::sourceAdded, this, &DictionaryMatchEngine::sourceAdded);
 }
 
 /* This function should be called from a different thread. */
@@ -40,17 +39,14 @@ QString DictionaryMatchEngine::lookupWord(const QString &word)
     m_lockers.insert(word, &data);
     m_wordLock.unlock();
 
-    QMetaObject::invokeMethod(this, "sourceAdded", Qt::QueuedConnection, Q_ARG(const QString&, word));
+    QMetaObject::invokeMethod(this, "sourceAdded", Qt::QueuedConnection, Q_ARG(const QString &, word));
     QMutexLocker locker(&data.mutex);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    if (!data.waitCondition.wait(&data.mutex, 30 * 1000)) // Timeout after 30 seconds
-#else
-    if (!data.waitCondition.wait(&data.mutex, QDeadlineTimer(30 * 1000))) // Timeout after 30 seconds
-#endif
+    if (!data.waitCondition.wait(&data.mutex, QDeadlineTimer(30 * 1000))) { // Timeout after 30 seconds
         qDebug() << "The dictionary data engine timed out (word:" << word << ")";
+    }
     locker.unlock();
 
-    QMetaObject::invokeMethod(this, "sourceRemoved", Qt::QueuedConnection, Q_ARG(const QString&, word));
+    QMetaObject::invokeMethod(this, "sourceRemoved", Qt::QueuedConnection, Q_ARG(const QString &, word));
     // after a timeout, if dataUpdated gets m_wordLock here, it can lock data->mutex successfully.
 
     m_wordLock.lockForWrite();
@@ -75,8 +71,9 @@ void DictionaryMatchEngine::sourceRemoved(const QString &source)
 
 void DictionaryMatchEngine::dataUpdated(const QString &source, const Plasma::DataEngine::Data &result)
 {
-    if (!result.contains(QLatin1String("text")))
+    if (!result.contains(QLatin1String("text"))) {
         return;
+    }
 
     QString definition(result[QLatin1String("text")].toString());
 
@@ -90,4 +87,3 @@ void DictionaryMatchEngine::dataUpdated(const QString &source, const Plasma::Dat
     }
     m_wordLock.unlock();
 }
-
