@@ -6,15 +6,15 @@
 #ifndef DICTIONARYRUNNER_H
 #define DICTIONARYRUNNER_H
 
-#include <KRunner/AbstractRunner>
 #include "dictionarymatchengine.h"
+#include <KRunner/AbstractRunner>
 
 class DictionaryRunner : public Plasma::AbstractRunner
 {
     Q_OBJECT
 
 public:
-    explicit DictionaryRunner(QObject *parent, const QVariantList &args);
+    explicit DictionaryRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
     void match(Plasma::RunnerContext &context) override;
     void reloadConfiguration() override;
 
@@ -24,7 +24,6 @@ private:
 
 protected Q_SLOTS:
     void init() override;
-
 };
 
 #endif
